@@ -6,7 +6,7 @@
 //                                                         //
 // Primary Business: Brisbane, Queensland, Australia       //
 // Licensed under the Open Software License version 3.0    //
-// http://www.opensource.org/licenses/osl-3.0.php          //
+// http://www.apache.org/licenses/LICENSE-2.0          //
 //                                                         //
 /////////////////////////////////////////////////////////////
 
@@ -621,6 +621,17 @@ namespace esys
       getLatticeMaster().addTaggedPairIG(p,tag1,mask1,tag2,mask2);
     }
 
+    void LsmMpiPy::createFrictionInteractGrpTag(const FrictionPrmsPy &prms,
+                                                   int tag1, int mask1,
+                                                   int tag2, int mask2)
+    {
+      FrictionPrmsPy p=prms;
+
+      p.setTimeStepSize(getTimeStepSize());
+      getNameTypeMap()[p.getName()] = p.getTypeString();
+      getLatticeMaster().addTaggedPairIG(p,tag1,mask1,tag2,mask2);
+    }
+
 
     void LsmMpiPy::createNRotFrictionInteractGrpTag(const NRotFrictionPrmsPy &prms,
 						   int tag1, int mask1,
@@ -2234,6 +2245,17 @@ namespace esys
           arg("mask2")
         )
       )
+      .def(
+        "createInteractionGroupTagged",
+        &LsmMpiPy::createFrictionInteractGrpTag,
+        (
+          arg("prms"),
+          arg("tag1"),
+          arg("mask1"),
+          arg("tag2"),
+          arg("mask2")
+        )
+      )
       .def(
         "createInteractionGroupTagged",
         &LsmMpiPy::createNRotFrictionInteractGrpTag,
